@@ -21,8 +21,7 @@
 #ifndef _ANJUTA_STATUS_H_
 #define _ANJUTA_STATUS_H_
 
-#include <libgnomeui/gnome-appbar.h>
-#include <libgnome/gnome-macros.h>
+#include <gtk/gtkhbox.h>
 
 G_BEGIN_DECLS
 
@@ -38,13 +37,13 @@ typedef struct _AnjutaStatusClass AnjutaStatusClass;
 
 struct _AnjutaStatus
 {
-	GnomeAppBar parent;
+	GtkHBox parent;
 	AnjutaStatusPriv *priv;
 };
 
 struct _AnjutaStatusClass
 {
-	GnomeAppBarClass parent_class;
+	GtkHBoxClass parent_class;
 	
 	/* signals */
 	void (*busy) (AnjutaStatus *status, gboolean state);
@@ -56,8 +55,8 @@ GtkWidget* anjuta_status_new (void);
 /* Status bar text manipulation */
 void anjuta_status_set (AnjutaStatus *status, const gchar * mesg, ...);
 void anjuta_status_push (AnjutaStatus *status, const gchar * mesg, ...);
-#define anjuta_status_pop(obj) gnome_appbar_pop(GNOME_APPBAR((obj)));
-#define anjuta_status_clear_stack(obj) gnome_appbar_clear_stack(GNOME_APPBAR((obj)));
+void anjuta_status_pop (AnjutaStatus *status);
+void anjuta_status_clear_stack (AnjutaStatus *status);
 void anjuta_status_busy_push (AnjutaStatus *status);
 void anjuta_status_busy_pop (AnjutaStatus *status);
 void anjuta_status_set_default (AnjutaStatus *status, const gchar *label,
@@ -75,6 +74,8 @@ void anjuta_status_disable_splash (AnjutaStatus *status,
 void anjuta_status_progress_add_ticks (AnjutaStatus *status, gint ticks);
 void anjuta_status_progress_tick (AnjutaStatus *status,
 								  GdkPixbuf *icon, const gchar *text);
+void anjuta_status_progress_increment_ticks (AnjutaStatus *status, gint ticks,
+											 const gchar *text);
 void anjuta_status_progress_pulse (AnjutaStatus *status, const gchar *text);
 void anjuta_status_progress_reset (AnjutaStatus *status);
 
